summaryrefslogtreecommitdiffstats
path: root/src/metadata/asf/asfattribute.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/metadata/asf/asfattribute.h')
-rw-r--r--src/metadata/asf/asfattribute.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/metadata/asf/asfattribute.h b/src/metadata/asf/asfattribute.h
index 9a8e3c9..9624f33 100644
--- a/src/metadata/asf/asfattribute.h
+++ b/src/metadata/asf/asfattribute.h
@@ -45,7 +45,7 @@ namespace TagLib
BytesType = 1,
BoolType = 2,
DWordType = 3,
- QWordType = 4,
+ TQWordType = 4,
WordType = 5,
GuidType = 6
};
@@ -71,7 +71,7 @@ namespace TagLib
Attribute(unsigned int value);
/*!
* Constructs an attribute with \a key and a QWordType \a value.
*/
Attribute(unsigned long long value);
@@ -121,7 +121,7 @@ namespace TagLib
unsigned int toUInt() const;
/*!
* Returns the QWordType \a value.
*/
unsigned long long toULongLong() const;
@@ -71,7 +71,7 @@ namespace TagLib
Attribute(unsigned int value);
/*!
- * Constructs an attribute with \a key and a QWordType \a value.
+ * Constructs an attribute with \a key and a TQWordType \a value.
*/
Attribute(unsigned long long value);
@@ -121,7 +121,7 @@ namespace TagLib
unsigned int toUInt() const;
/*!
- * Returns the QWordType \a value.
+ * Returns the TQWordType \a value.
*/
unsigned long long toULongLong() const;